@@ -1,5 +1,5 @@
 from syncode.infer import Syncode
-from syncode.grammar_decoder import SyncodeLogitsProcessor
+from syncode.grammar_mask.logits_processor import SyncodeLogitsProcessor
 from syncode.parsers.grammars import Grammar
 import syncode.common as common
 
