@@ -50,6 +50,8 @@ class Syncode:
         parser: Literal["lr", "lalr"] = "lalr",
         seed: Optional[int] = None,
         opp: bool = True,
+        device_map: Optional[str] = None,
+        indent: bool = False,
         **kwargs
     ):  
         # Check inputs
@@ -85,7 +87,7 @@ class Syncode:
         self.grammar = Grammar(grammar) if self._is_grammar_mode() else None
 
         # Load model and tokenizer
-        model = common.load_model(self.model_name, device, quantize)
+        model = common.load_model(self.model_name, device, quantize, device_map)
         tokenizer = common.load_tokenizer(self.model_name)
         
         # Initialize grammar decoder if needed
@@ -101,6 +103,7 @@ class Syncode:
                 dev_mode=dev_mode,
                 parser=parser,
                 mode=mode,
+                indent=indent
             )
 
         # Set default max new tokens if not provided
@@ -259,6 +262,7 @@ def main(
     parse_output_only: bool = True,
     prompt_type: str = 'original',
     format_tabs: bool = False,
+    device_map: Optional[str] = None,
     **kwargs
 ):
     """Run Syncode with the specified configuration.
@@ -309,6 +313,7 @@ def main(
         seed=seed, 
         opp=opp,
         parse_output_only=parse_output_only,
+        device_map=device_map,
         **kwargs
     )
     
