@@ -59,7 +59,8 @@ class MaskStore:
             self._vocab, 
             eos_token_id=self.eos_token_id,
             special_token_ids=self.special_token_ids, 
-            indent=indent, mode=mode
+            indent=indent, 
+            mode=mode
             )
         terminal_names = [terminal.name for terminal in terminals]
 
@@ -106,8 +107,10 @@ class MaskStore:
         if use_cache and os.path.exists(fsm_path):
             try:
                 with open(fsm_path, 'rb') as f:
-                    mask_store = pickle.load(f)
-                    return mask_store
+                    mask_store: MaskStore = pickle.load(f)
+                    if mask_store.indentation == indent:
+                        return mask_store
+                    
             except Exception as e:
                 logger.warning(f"Error loading mask store: {e}")
                 
@@ -269,10 +272,10 @@ class MaskStore:
         if (self._fsms.initial(fsm_state.terminal) == fsm_state or self._fsms.is_final(fsm_state)) and self._ignore_whitespace:
             if isinstance(remainder, bytes):
                 # For bytes, use lstrip() to remove all leading whitespace
-                remainder = remainder.lstrip()
+                remainder = remainder.lstrip(b' ')
             elif isinstance(remainder, str):
                 # For strings, use lstrip() to remove all leading whitespace
-                remainder = remainder.lstrip()
+                remainder = remainder.lstrip(' ')
         return remainder
 
     def _lookup_next_tokens_for_fsm_state(self, fsm_state: JointFSMState, next_terminal) -> torch.Tensor:
